
{# import recaptcha_ajax.js in your body  #} 
{# <script type="text/javascript" src="//www.google.com/recaptcha/api/js/recaptcha_ajax.js"></script> #}

<div id="Recap"></div>
<script type="text/javascript">
  var RecaptchaOptions = {{ options }};
  Recaptcha.create("{{ public_key }}",
    "Recap",
    {
      theme: RecaptchaOptions['theme'] || "red",
      callback: Recaptcha.focus_response_field
    }, 
    RecaptchaOptions
  );
</script>


{% comment %}
<noscript>
  <iframe src="{{api_server}}/noscript?k={{public_key}}{{error_param}}" height="300" width="500" frameborder="0"></iframe><br />
  <textarea name="recaptcha_challenge_field" rows="3" cols="40"></textarea>
  <input type='hidden' name='recaptcha_response_field' value='manual_challenge' />
</noscript>
{% endcomment %}